# About

## Development

ESSsans is an open source project by the [European Spallation Source ERIC](https://ess.eu/) (ESS).

## License

ESSsans is available as open source under the [BSD-3 license](https://opensource.org/license/BSD-3-Clause).

## Citing ESSsans

Please cite the following:

[![DOI](https://zenodo.org/badge/685058554.svg)](https://zenodo.org/doi/10.5281/zenodo.10057069)

To cite a specific version of ESSsans, select the desired version on Zenodo to get the corresponding DOI.

## Older versions of the documentation

Older versions of the documentation pages can be found under the assets of each [release](https://github.com/scipp/esssans/releases).
Simply download the archive, unzip and view locally in a web browser.

## Source code and development

ESSsans is hosted and developed [on GitHub](https://github.com/scipp/esssans).
